.. _references:

Publications
============

Kümmel et al., 2021
-------------------

Rapid brain structure and tumour margin detection on whole frozen tissue sections by fast multiphotometric mid-infrared scanning.

.. figure:: https://media.springernature.com/lw685/springer-static/image/art%3A10.1038%2Fs41598-021-90777-4/MediaObjects/41598_2021_90777_Fig5_HTML.png?as=webp
   :alt: Figure from Kümmel et al. 2021
   :width: 480px
   :align: center
   :target: https://doi.org/10.1038/s41598-021-90777-4

   https://doi.org/10.1038/s41598-021-90777-4


Heintz et al., 2021
-------------------

Design of a Multimodal Imaging System and Its First Application to Distinguish Grey and White Matter of Brain Tissue. A Proof-of-Concept-Study.

.. figure:: https://www.mdpi.com/applsci/applsci-11-04777/article_deploy/html/images/applsci-11-04777-g003.png
   :alt: DOI logo for Heintz et al. 2021
   :width: 480px
   :align: center
   :target: https://doi.org/10.3390/app11114777

   https://doi.org/10.3390/app11114777


Manser et al., 2023
-------------------

Innovative Imaging Techniques: A Conceptual Exploration of Multi-Modal Raman Light Sheet Microscopy.

.. figure:: https://www.mdpi.com/micromachines/micromachines-14-01739/article_deploy/html/images/micromachines-14-01739-g012.png
   :alt: DOI logo for Manser et al. 2023
   :width: 480px
   :align: center
   :target: https://doi.org/10.3390/mi14091739

   https://doi.org/10.3390/mi14091739


Nachtmann et al., 2023
----------------------

Three-Dimensional, Molecule-Sensitive Mapping of Structured Falling Liquid Films Using Raman Spectroscopy.

.. figure:: https://onlinelibrary.wiley.com/cms/asset/82d41b4e-e935-4bc0-af07-07623713e130/cite202300048-fig-0002-m.jpg
   :alt: DOI logo for Nachtmann et al. 2023
   :width: 480px
   :align: center
   :target: https://doi.org/10.1002/cite.202300048

   https://doi.org/10.1002/cite.202300048


van Marwick et al., 2024
------------------------

Rapid chemical detection and segmentation of latent fingerprints by means of a novel middle-infrared scanning method.

.. figure:: https://pubs.rsc.org/image/article/2024/an/d4an00367e/d4an00367e-f3.gif
   :alt: DOI logo for van Marwick et al. 2024
   :width: 480px
   :align: center
   :target: https://doi.org/10.1039/D4AN00367E

   https://doi.org/10.1039/D4AN00367E

